.. Skosprovider documentation master file, created by
   sphinx-quickstart on Sun Apr  7 22:37:01 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Content
=======

.. toctree::
   :maxdepth: 2

   intro
   usage
   development
   api
   changes
   glossary

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

